@@ -34,7 +34,7 @@
 #include <private/xdgbasedirs_p.h>
 #include <private/protocol_p.h>
 #include <private/scope_p.h>
-#include <shared/akstandarddirs.h>
+#include <private/standarddirs_p.h>
 #include <shared/akapplication.h>
 
 #include "storage/dbconfig.h"
@@ -140,7 +140,7 @@ TestScenario::List FakeAkonadiServer::loginScenario(const QByteArray &sessionId)
         TestScenario::create(0, TestScenario::ServerCmd,
                              Protocol::HelloResponse(QStringLiteral("Akonadi"),
                                                      QStringLiteral("Not Really IMAP server"),
-                                                     Connection::protocolVersion())),
+                                                     Protocol::version())),
         TestScenario::create(1,TestScenario::ClientCmd,
                              Protocol::LoginCommand(sessionId.isEmpty() ? instanceName().toLatin1() : sessionId)),
         TestScenario::create(1, TestScenario::ServerCmd,
@@ -148,17 +148,6 @@ TestScenario::List FakeAkonadiServer::loginScenario(const QByteArray &sessionId)
     };
 }
 
-TestScenario::List FakeAkonadiServer::selectCollectionScenario(const QString &name)
-{
-    const Collection collection = Collection::retrieveByName(name);
-    return {
-        TestScenario::create(2, TestScenario::ClientCmd,
-                             Protocol::SelectCollectionCommand(collection.id())),
-        TestScenario::create(2, TestScenario::ServerCmd,
-                             Protocol::SelectCollectionResponse())
-    };
-}
-
 TestScenario::List FakeAkonadiServer::selectResourceScenario(const QString &name)
 {
     const Resource resource = Resource::retrieveByName(name);
@@ -177,7 +166,7 @@ bool FakeAkonadiServer::init()
     qputenv("XDG_DATA_HOME", qPrintable(QString(basePath() + QLatin1String("/local"))));
     qputenv("XDG_CONFIG_HOME", qPrintable(QString(basePath() + QLatin1String("/config"))));
     qputenv("AKONADI_INSTANCE", qPrintable(instanceName()));
-    QSettings settings(AkStandardDirs::serverConfigFile(XdgBaseDirs::WriteOnly), QSettings::IniFormat);
+    QSettings settings(StandardDirs::serverConfigFile(XdgBaseDirs::WriteOnly), QSettings::IniFormat);
     settings.beginGroup(QLatin1String("General"));
     settings.setValue(QLatin1String("Driver"), QLatin1String("QSQLITE3"));
     settings.endGroup();
@@ -256,7 +245,7 @@ bool FakeAkonadiServer::quit()
     // Stop listening for connections
     close();
 
-    const QCommandLineParser &args = AkApplication::instance()->commandLineArguments();
+    const QCommandLineParser &args = AkApplicationBase::instance()->commandLineArguments();
     if (!args.isSet(QLatin1String("no-cleanup"))) {
         deleteDirectory(basePath());
         qDebug() << "Cleaned up" << basePath();
@@ -286,9 +275,9 @@ void FakeAkonadiServer::incomingConnection(quintptr socketDescriptor)
     FakeConnection *connection = new FakeConnection(socketDescriptor, thread);
     thread->start();
 
-    connect(connection, SIGNAL(disconnected()), thread, SLOT(quit()));
-    connect(thread, SIGNAL(finished()), thread, SLOT(deleteLater()));
-    connect(thread, SIGNAL(finished()), connection, SLOT(deleteLater()));
+    connect(connection, &Connection::disconnected, thread, &QThread::quit);
+    connect(thread, &QThread::finished, thread, &QObject::deleteLater);
+    connect(thread, &QThread::finished, connection, &QObject::deleteLater);
 
     mNotificationSpy = new QSignalSpy(connection->notificationCollector(),
                                       SIGNAL(notify(Akonadi::Protocol::ChangeNotification::List)));
@@ -300,7 +289,7 @@ void FakeAkonadiServer::runTest()
     QVERIFY(listen(socketFile()));
 
     mServerLoop = new QEventLoop(this);
-    connect(mClient, SIGNAL(finished()), mServerLoop, SLOT(quit()));
+    connect(mClient, &QThread::finished, mServerLoop, &QEventLoop::quit);
 
     // Start the client: the client will connect to the server and will
     // start playing the scenario
