@@ -39,8 +39,7 @@
 #include <utils.h>
 
 #include <shared/akdebug.h>
-#include <private/xdgbasedirs_p.h>
-#include <private/protocol_p.h>
+#include <private/externalpartstorage_p.h>
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDir>
@@ -59,6 +58,7 @@
 #include <QtSql/QSqlField>
 #include <QtSql/QSqlQuery>
 
+using namespace Akonadi;
 using namespace Akonadi::Server;
 
 static QMutex sTransactionMutex;
@@ -95,8 +95,8 @@ DataStore::DataStore()
         // without properly reporting the error
         m_keepAliveTimer = new QTimer(this);
         m_keepAliveTimer->setInterval(3600 * 1000);
-        QObject::connect(m_keepAliveTimer, SIGNAL(timeout()),
-                         this, SLOT(sendKeepAliveQuery()));
+        QObject::connect(m_keepAliveTimer, &QTimer::timeout,
+                         this, &DataStore::sendKeepAliveQuery);
         m_keepAliveTimer->start();
     }
 }
@@ -167,8 +167,8 @@ bool DataStore::init()
     }
     s_hasForeignKeyConstraints = initializer->hasForeignKeyConstraints();
 
-    if (QFile::exists(QLatin1String(":dbupdate.xml"))) {
-        DbUpdater updater(m_database, QLatin1String(":dbupdate.xml"));
+    if (QFile::exists(QStringLiteral(":dbupdate.xml"))) {
+        DbUpdater updater(m_database, QStringLiteral(":dbupdate.xml"));
         if (!updater.run()) {
             return false;
         }
@@ -209,6 +209,11 @@ DataStore *DataStore::self()
     return sInstances.localData();
 }
 
+bool DataStore::hasDataStore()
+{
+    return sInstances.hasLocalData();
+}
+
 /* --- ItemFlags ----------------------------------------------------- */
 
 bool DataStore::setItemsFlags(const PimItem::List &items, const QVector<Flag> &flags,
@@ -754,7 +759,8 @@ bool DataStore::cleanupCollection(Collection &collection)
 
     try {
         while (qb.query().next()) {
-            PartHelper::removeFile(PartHelper::resolveAbsolutePath(qb.query().value(0).toByteArray()));
+            ExternalPartStorage::self()->removePartFile(
+                ExternalPartStorage::resolveAbsolutePath(qb.query().value(0).toByteArray()));
         }
     } catch (const PartHelperException &e) {
         akDebug() << e.what();
@@ -941,7 +947,7 @@ void DataStore::activeCachePolicy(Collection &col)
     col.setCachePolicyCheckInterval(-1);
     col.setCachePolicyCacheTimeout(-1);
     col.setCachePolicySyncOnDemand(false);
-    col.setCachePolicyLocalParts(QLatin1String("ALL"));
+    col.setCachePolicyLocalParts(QStringLiteral("ALL"));
 }
 
 QVector<Collection> DataStore::virtualCollections(const PimItem &item)
@@ -1099,7 +1105,7 @@ bool DataStore::unhideAllPimItems()
 
     try {
         return PartHelper::remove(Part::partTypeIdFullColumnName(),
-                                  PartTypeHelper::fromFqName(QLatin1String("ATR"), QLatin1String("HIDDEN")).id());
+                                  PartTypeHelper::fromFqName(QStringLiteral("ATR"), QStringLiteral("HIDDEN")).id());
     } catch (...) {
     } // we can live with this failing
 
@@ -1204,10 +1210,10 @@ void DataStore::debugLastDbError(const char *actionDescription) const
     akError() << "  Last database error:" << m_database.lastError().databaseText();
 
     Tracer::self()->error("DataStore (Database Error)",
-                          QString::fromLatin1("%1\nDriver said: %2\nDatabase said:%3")
-                          .arg(QString::fromLatin1(actionDescription))
-                          .arg(m_database.lastError().driverText())
-                          .arg(m_database.lastError().databaseText()));
+                          QStringLiteral("%1\nDriver said: %2\nDatabase said:%3")
+                          .arg(QString::fromLatin1(actionDescription),
+                               m_database.lastError().driverText(),
+                               m_database.lastError().databaseText()));
 }
 
 void DataStore::debugLastQueryError(const QSqlQuery &query, const char *actionDescription) const
@@ -1218,9 +1224,9 @@ void DataStore::debugLastQueryError(const QSqlQuery &query, const char *actionDe
     akError() << "  Last database error:" << m_database.lastError().databaseText();
 
     Tracer::self()->error("DataStore (Database Query Error)",
-                          QString::fromLatin1("%1: %2")
-                          .arg(QString::fromLatin1(actionDescription))
-                          .arg(query.lastError().text()));
+                          QStringLiteral("%1: %2")
+                          .arg(QString::fromLatin1(actionDescription),
+                               query.lastError().text()));
 }
 
 // static
@@ -1230,13 +1236,13 @@ QString DataStore::dateTimeFromQDateTime(const QDateTime &dateTime)
     if (utcDateTime.timeSpec() != Qt::UTC) {
         utcDateTime.toUTC();
     }
-    return utcDateTime.toString(QLatin1String("yyyy-MM-dd hh:mm:ss"));
+    return utcDateTime.toString(QStringLiteral("yyyy-MM-dd hh:mm:ss"));
 }
 
 // static
 QDateTime DataStore::dateTimeToQDateTime(const QByteArray &dateTime)
 {
-    return QDateTime::fromString(QString::fromLatin1(dateTime), QLatin1String("yyyy-MM-dd hh:mm:ss"));
+    return QDateTime::fromString(QString::fromLatin1(dateTime), QStringLiteral("yyyy-MM-dd hh:mm:ss"));
 }
 
 void DataStore::addQueryToTransaction(const QSqlQuery &query, bool isBatch)
@@ -1335,7 +1341,7 @@ bool DataStore::beginTransaction()
     if (m_transactionLevel == 0) {
         TRANSACTION_MUTEX_LOCK;
         if (DbType::type(m_database) == DbType::Sqlite) {
-            m_database.exec(QLatin1String("BEGIN IMMEDIATE TRANSACTION"));
+            m_database.exec(QStringLiteral("BEGIN IMMEDIATE TRANSACTION"));
             if (m_database.lastError().isValid()) {
                 debugLastDbError("DataStore::beginTransaction (SQLITE)");
                 TRANSACTION_MUTEX_UNLOCK;
@@ -1420,6 +1426,6 @@ void DataStore::sendKeepAliveQuery()
 {
     if (m_database.isOpen()) {
         QSqlQuery query(m_database);
-        query.exec(QLatin1String("SELECT 1"));
+        query.exec(QStringLiteral("SELECT 1"));
     }
 }
